==> 1.0.0.zip: terraform-provider-dynamix/samples/cloudapi/account/data_account_flipgroups_list/main.tf <==
/*
Пример использования
Получение информации о flipgroups, используемых аккаунтом
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "dynamix_account_flipgroups_list" "afgl" {
  #id аккаунта
  #обязательный параметр
  #тип - целое число
  account_id = 1111

  #фильтр по имени flipgroup
  #опциональный параметр
  #тип - строка
  #name = "test"

  #фильтр по id vins
  #опциональный параметр
  #тип - целое число
  #vins_id = 100

  #фильтр по имени vins
  #опциональный параметр
  #тип - строка
  #vins_name = "test"

  #фильтр по id extnet
  #опциональный параметр
  #тип - целое число
  #extnet_id = 100

  #фильтр по IP
  #опциональный параметр
  #тип - строка
  #by_ip = "1.1.1.1.1"

  #фильтр по id flipgroup
  #опциональный параметр
  #тип - целое число
  #flipgroup_id = 100

  #кол-во страниц для вывода
  #опицональный параметр 
  #тип - целое число
  #page = 1

  #размер страницы
  #опицональный параметр 
  #тип - целое число
  #size = 1
}

output "test" {
  value = data.dynamix_account_flipgroups_list.afgl
}

==> 1.2.1.zip: terraform-provider-dynamix/samples/cloudapi/account/data_account_flipgroups_list/main.tf <==
/*
Пример использования
Получение информации о flipgroups, используемых аккаунтом
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DYNAMIX_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DYNAMIX_OAUTH2_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "dynamix_account_flipgroups_list" "afgl" {
  #id аккаунта
  #обязательный параметр
  #тип - целое число
  account_id = 1111

  #фильтр по имени flipgroup
  #опциональный параметр
  #тип - строка
  #name = "test"

  #фильтр по id vins
  #опциональный параметр
  #тип - целое число
  #vins_id = 100

  #фильтр по имени vins
  #опциональный параметр
  #тип - строка
  #vins_name = "test"

  #фильтр по id extnet
  #опциональный параметр
  #тип - целое число
  #extnet_id = 100

  #фильтр по IP
  #опциональный параметр
  #тип - строка
  #by_ip = "1.1.1.1.1"

  #фильтр по id flipgroup
  #опциональный параметр
  #тип - целое число
  #flipgroup_id = 100

  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #тип - строка
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  #sort_by = "+name"

  #кол-во страниц для вывода
  #опицональный параметр 
  #тип - целое число
  #page = 1

  #размер страницы
  #опицональный параметр 
  #тип - целое число
  #size = 1
}

output "test" {
  value = data.dynamix_account_flipgroups_list.afgl
}
